unit control;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, fkomp, uPresets;

type
  Tf_control = class(TForm)
    b_close: TButton;
    b_calc: TButton;
    rg_mode: TRadioGroup;
    rb_julia: TRadioButton;
    rb_mandel: TRadioButton;
    k_z1: Tf_komponentedit;
    k_z2: Tf_komponentedit;
    k_c1: Tf_komponentedit;
    k_c2: Tf_komponentedit;
    GroupBox1: TGroupBox;
    cb_speedboost: TCheckBox;
    cb_onzoomrecalc: TCheckBox;
    CheckBox1: TCheckBox;
    od_presets: TOpenDialog;
    sd_presets: TSaveDialog;
    lb_presets: TListBox;
    e_presetname: TEdit;
    b_savepreset: TButton;
    b_savepresets: TButton;
    b_loadpresets: TButton;
    cb_onpresetrecalc: TCheckBox;
    procedure b_closeClick(Sender: TObject);
    procedure b_calcClick(Sender: TObject);
    procedure rb_juliaClick(Sender: TObject);
    procedure rb_mandelClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cb_speedboostClick(Sender: TObject);
    procedure b_savepresetClick(Sender: TObject);
    procedure b_savepresetsClick(Sender: TObject);
    procedure b_loadpresetsClick(Sender: TObject);
    procedure b_loadpresetClick(Sender: TObject);
    procedure lb_presetsDblClick(Sender: TObject);
  private
    { Private-Deklarationen }
  public
    { Public-Deklarationen }
  end;

var
  f_control: Tf_control;


implementation

uses screen;

{$R *.DFM}

procedure Tf_control.b_closeClick(Sender: TObject);
begin
  close;
end;

procedure Tf_control.b_calcClick(Sender: TObject);
begin
  f_screen.show;
  f_screen.setvar(k_z1.komp,k_z2.komp,k_c1.komp,k_c2.komp);
  f_screen.calc;
end;

procedure Tf_control.rb_juliaClick(Sender: TObject);
begin
  if rb_julia.Checked then begin
    f_screen.setmode(c_julia);
    k_z1.l_titel.Caption:='z1 (Anfang)';
    k_z2.l_titel.Caption:='z2 (Ende)';
    k_c1.l_titel.Caption:='c';
    k_c2.l_titel.Caption:='nicht aktiv';
  end;
end;

procedure Tf_control.rb_mandelClick(Sender: TObject);
begin
  if rb_mandel.Checked then begin
    f_screen.setmode(c_mandel);
    k_z1.l_titel.Caption:='z';
    k_z2.l_titel.Caption:='nicht aktiv';
    k_c1.l_titel.Caption:='c1 (Anfang)';
    k_c2.l_titel.Caption:='c2 (Ende)';
  end;
end;

procedure Tf_control.FormCreate(Sender: TObject);
var
  vp_run: integer;
  vp_preset: uP_r_preset;
begin
  rb_julia.Checked:=true;
  f_screen.setmode(c_julia);
  k_z1.e_x.text:='-2';
  k_z1.e_y.text:='-0,78125';
  k_z2.e_x.text:='0,5';
  k_z2.e_y.text:='0,78125';
  k_c1.e_x.text:='-1';
  k_c1.e_y.text:='0';
  k_c2.e_x.text:='0';
  k_c2.e_y.text:='0';

  // Daten laden
  up_loadfromfile('presets.txt');

  // Daten importieren
  lb_presets.clear;
  if up_v_numberofpresets>0 then
    for vp_run:= 1 to up_v_numberofpresets do begin
      vp_preset:=up_getpreset(vp_run);
      if vp_preset.Typ=c_julia then
        lb_presets.items.Append('Julia: '+vp_preset.Name)
      else
        lb_presets.items.Append('Mandelbrot: '+vp_preset.Name);
    end;
end;

procedure Tf_control.cb_speedboostClick(Sender: TObject);
begin
  v_speedboost:=cb_speedboost.checked;
end;

procedure Tf_control.b_savepresetClick(Sender: TObject);
var
  vp_preset: uP_r_preset;
begin
  // Variablen speichern
  with vp_preset do begin
    typ:=v_mode;
    name:=e_presetname.text;
    x1x := k_z1.e_x.text;
    x1y := k_z1.e_y.text;
    x2x := k_z2.e_x.text;
    x2y := k_z2.e_y.text;
    c1x := k_c1.e_x.text;
    c1y := k_c1.e_y.text;
    c2x := k_c2.e_x.text;
    c2y := k_c2.e_y.text;
  end;
  if uP_addpreset(vp_preset)=0 then
      lb_presets.items.Append(e_presetname.text);
end;

procedure Tf_control.b_savepresetsClick(Sender: TObject);
begin
  sd_presets.Execute;
  uP_savetofile(sd_presets.FileName);
end;

procedure Tf_control.b_loadpresetsClick(Sender: TObject);
var
  vp_run:integer;
  vp_preset: up_r_preset;
begin
  // Daten laden
  od_presets.Execute;
  up_loadfromfile(od_presets.FileName);

  // Daten importieren
  lb_presets.clear;
  if up_v_numberofpresets>0 then
    for vp_run:= 1 to up_v_numberofpresets do begin
      vp_preset:=up_getpreset(vp_run);
      if vp_preset.Typ=c_julia then
        lb_presets.items.Append('Julia: '+vp_preset.Name)
      else
        lb_presets.items.Append('Mandelbrot: '+vp_preset.Name);
    end;
end;

procedure Tf_control.b_loadpresetClick(Sender: TObject);
var
  vp_preset: up_r_preset;
begin
  if lb_presets.ItemIndex>=0 then begin
    vp_preset:=up_getpreset(lb_presets.ItemIndex+1);
    with vp_preset do begin
      if typ=c_julia then
        begin
          rb_julia.Checked:=true;
          rb_mandel.checked:=false;
        end
      else
        begin
          rb_julia.Checked:=false;
          rb_mandel.checked:=true;
        end;
      k_z1.e_x.Text:=x1x;
      k_z1.e_y.Text:=x1y;
      k_z2.e_x.Text:=x2x;
      k_z2.e_y.Text:=x2y;
      k_c1.e_x.Text:=c1x;
      k_c1.e_y.Text:=c1y;
      k_c2.e_x.Text:=c2x;
      k_c2.e_y.Text:=c2y;
    end;
  end;
end;

procedure Tf_control.lb_presetsDblClick(Sender: TObject);
var
  vp_preset: up_r_preset;
begin
  if lb_presets.ItemIndex>=0 then begin
    vp_preset:=up_getpreset(lb_presets.ItemIndex+1);
    with vp_preset do begin
      if typ=c_julia then
        begin
          rb_julia.Checked:=true;
          rb_mandel.checked:=false;
        end
      else
        begin
          rb_julia.Checked:=false;
          rb_mandel.checked:=true;
        end;
      k_z1.e_x.Text:=x1x;
      k_z1.e_y.Text:=x1y;
      k_z2.e_x.Text:=x2x;
      k_z2.e_y.Text:=x2y;
      k_c1.e_x.Text:=c1x;
      k_c1.e_y.Text:=c1y;
      k_c2.e_x.Text:=c2x;
      k_c2.e_y.Text:=c2y;
    end;
  end;
  if cb_onpresetrecalc.checked then b_calcclick(Sender);
end;

end.
