unit uPresets;

interface

type
  uP_r_preset= record
    Typ:integer;
    Name: string[50];
    x1x,x1y,x2x,x2y,c1x,c1y,c2x,c2y: string[20];
  end;

function up_addpreset(vp_preset:uP_r_preset):integer;
function up_getpreset(vp_index: integer):up_r_preset;

procedure up_savetofile(vp_filename:string);
procedure up_loadfromfile(vp_filename:string);

var
  uP_v_numberofpresets: integer=0;

implementation

uses
  sysutils;

var
  v_presets: array[0..50] of uP_r_preset;

function up_addpreset(vp_preset:uP_r_preset):integer;
begin
  if up_v_numberofpresets<50 then
  begin
    inc(up_v_numberofpresets);
    v_presets[up_v_numberofpresets]:=vp_preset;
    result:=0;
  end
  else
    result:=1;
end;

procedure up_savetofile(vp_filename:string);
var
  vp_run: integer;
  vp_file: textfile;
begin
  if uP_v_numberofpresets>0 then
    begin
      assignfile(vp_file, vp_filename);
      rewrite(vp_file);

      for vp_run := 1 to uP_v_numberofpresets do
        begin
          with v_presets[vp_run] do
            writeln(vp_file,'PRESET ("'+name+'"; '+inttostr(typ)+'; '
                           +x1x+'; '+x1y+'; '+x2x+'; '+x2y+'; '
                           +c1x+'; '+c1y+'; '+c2x+'; '+c2y+')');
        end; // for vp_run := 0 to uP_v_numberofpresets do
      closefile(vp_file);
    end;
end;

procedure up_loadfromfile(vp_filename:string);

var
  vp_file: file;

  function getnamefromfile:string;
  var
    vp_getnamefromfile: string;
    vp_char:char;
  begin
    vp_getnamefromfile := '';
    repeat
      blockread(vp_file,vp_char,1);
    until vp_char='"';
    {Anfang string}
    blockread(vp_file,vp_char,1);
    repeat
      vp_getnamefromfile := vp_getnamefromfile + vp_char;
      blockread(vp_file,vp_char,1);
    until vp_char='"';
    getnamefromfile:=vp_getnamefromfile;
  end;

  function getintfromfile:integer;
  var
    vp_getintfromfile: string;
    vp_int, vp_code: integer;
    vp_char:char;
  begin
    repeat
      blockread(vp_file,vp_char,1);
    until (vp_char='0')or(vp_char='1')or(vp_char='2')or(vp_char='3')or(vp_char='4')or
          (vp_char='5')or(vp_char='6')or(vp_char='7')or(vp_char='8')or(vp_char='9');
    {Anfang string}
    vp_getintfromfile:=vp_char;
    repeat
      blockread(vp_file,vp_char,1);
      vp_getintfromfile:=vp_getintfromfile+vp_char;
    until ((vp_char='0')or(vp_char='1')or(vp_char='2')or(vp_char='3')or(vp_char='4')or
          (vp_char='5')or(vp_char='6')or(vp_char='7')or(vp_char='8')or(vp_char='9'))= false ;
    val(copy(vp_getintfromfile,0,length(vp_getintfromfile)-1),vp_int,vp_code);
    seek(vp_file,filepos(vp_file)-1);
    getintfromfile:=vp_int;
  end;

  function getfloatfromfile:double;
  var
    vp_getfloatfromfile: string;
    vp_float: double;
    vp_char:char;
  begin
    repeat
      blockread(vp_file,vp_char,1);
    until (vp_char='0')or(vp_char='1')or(vp_char='2')or(vp_char='3')or(vp_char='4')or
          (vp_char='5')or(vp_char='6')or(vp_char='7')or(vp_char='8')or(vp_char='9')or
          (vp_char=',')or(vp_char='+')or(vp_char='-');
    {Anfang string}
    vp_getfloatfromfile:='';
    repeat
      vp_getfloatfromfile:=vp_getfloatfromfile+vp_char;
      blockread(vp_file,vp_char,1);
    until ((vp_char='0')or(vp_char='1')or(vp_char='2')or(vp_char='3')or(vp_char='4')or
          (vp_char='5')or(vp_char='6')or(vp_char='7')or(vp_char='8')or(vp_char='9')or(vp_char=','))= false ;
    vp_float:=strtofloat(vp_getfloatfromfile);
    seek(vp_file,filepos(vp_file)-1);
    result:=vp_float;
  end;

  procedure getpreset;
  var
    vp_char: char;
    vp_ident : string;
    vp_preset: up_r_preset;
  begin
    vp_ident:='';
    repeat
      blockread(vp_file,vp_char,1);
      case upcase(vp_char)of
        'A'..'Z','}': vp_ident:= vp_ident+upcase(vp_char)
        else vp_ident:='';
      end;
      if vp_ident = 'PRESET' then
        begin
          // Anfang der Daten suchen
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char='(');
          // Namen des Presets einlesem
          vp_preset.name:=getnamefromfile;
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // Typ auslesen
          vp_preset.typ:=getintfromfile;
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');

          // X1x auslesen
          vp_preset.x1x:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // X1y auslesen
          vp_preset.x1y:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // X2x auslesen
          vp_preset.x2x:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // X2y auslesen
          vp_preset.x2y:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');

          // C1x auslesen
          vp_preset.c1x:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // C1y auslesen
          vp_preset.c1y:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // C2x auslesen
          vp_preset.c2x:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=';');
          // C2y auslesen
          vp_preset.c2y:=floattostr(getfloatfromfile);
          repeat
            blockread(vp_file,vp_char,1);
          until (vp_char=')');
          up_addpreset(vp_preset);
        end // if vp_ident = 'PRESET' then
    until (eof(vp_file));


  end;

begin
  up_v_numberofpresets:=0;
  assignfile(vp_file, vp_filename);
  reset(vp_file,1);
  repeat
    getpreset;
  until eof(vp_file);
  closefile(vp_file);
end;

function up_getpreset(vp_index: integer):up_r_preset;
begin
  result:=v_presets[vp_index];
end;

end.
